@@ -16,10 +16,12 @@ from graphkb.match import (
 )
 from graphkb.types import Record, Statement
 from graphkb.util import FeatureNotFoundError, convert_to_rid_list
+from graphkb.constants import BASE_THERAPEUTIC_TERMS
+from graphkb.vocab import get_terms_set
 from progressbar import progressbar
 from requests.exceptions import HTTPError
 
-from .ipr import BASE_THERAPEUTIC_TERMS, convert_statements_to_alterations, get_terms_set
+from .ipr import convert_statements_to_alterations
 from .types import IprGene, IprGeneVariant, IprVariant, KbMatch
 from .util import convert_to_rid_set, logger
 
@@ -29,7 +31,7 @@ def get_therapeutic_associated_genes(graphkb_conn: GraphKBConnection) -> Set[str
     statements = graphkb_conn.query(
         {
             'target': 'Statement',
-            'filters': {'relevance': list(therapeutic_relevance)},
+            'filters': {'relevance': sorted(list(therapeutic_relevance))},
             'returnProperties': [
                 'conditions.@rid',
                 'conditions.@class',
@@ -38,7 +40,7 @@ def get_therapeutic_associated_genes(graphkb_conn: GraphKBConnection) -> Set[str
                 'conditions.reference2.@class',
                 'conditions.reference2.@rid',
             ],
-        }
+        },
     )
     genes = set()
 
@@ -66,7 +68,7 @@ def get_gene_information(
     """
     logger.info('fetching variant related genes list')
     variants = graphkb_conn.query(
-        {'target': 'Variant', 'returnProperties': ['@class', 'reference1', 'reference2']}
+        {'target': 'Variant', 'returnProperties': ['@class', 'reference1', 'reference2']},
     )
 
     gene_flags: Dict[str, Set[str]] = {
@@ -142,7 +144,7 @@ def get_statements_from_variants(
             'target': 'Statement',
             'filters': {'conditions': convert_to_rid_list(variants), 'operator': 'CONTAINSANY'},
             'returnProperties': return_props,
-        }
+        },
     )
     return statements
 
@@ -188,7 +190,10 @@ def get_ipr_statements_from_variants(
     ]
 
     for ipr_row in convert_statements_to_alterations(
-        graphkb_conn, inferred_statements, disease_name, convert_to_rid_set(inferred_matches),
+        graphkb_conn,
+        inferred_statements,
+        disease_name,
+        convert_to_rid_set(inferred_matches),
     ):
         new_row = KbMatch({'kbData': {'inferred': True}})
         new_row.update(ipr_row)
